@@ -60,8 +60,8 @@ void ui_fini();
 
 
 
-void edf_data_to_widgets( const sigfile::CEDFFile&);
-void widgets_to_edf_data( sigfile::CEDFFile&);
+static void edf_data_to_widgets( const sigfile::CEDFFile&);
+static void widgets_to_edf_data( sigfile::CEDFFile&);
 
 sigfile::CEDFFile *Fp;
 
@@ -93,9 +93,9 @@ list<SChannelTmp>
 list<SChannelTmp>::iterator
 	HTmpi;
 
-void current_channel_data_to_widgets();
-void widgets_to_current_channel_data();
-void sensitize_channel_nav_buttons();
+static void current_channel_data_to_widgets();
+static void widgets_to_current_channel_data();
+static void sensitize_channel_nav_buttons();
 
 size_t channel_no;
 
@@ -126,7 +126,7 @@ main( int argc, char **argv)
 		} else {
 			// aghui::pop_ok_message( NULL, "Usage: %s file.edf", argv[0]);
 			GtkWidget *f_chooser = gtk_file_chooser_dialog_new(
-				"EDFHEd: Choose a file to edit",
+				"edfhed-gtk: Choose a file to edit",
 				NULL,
 				GTK_FILE_CHOOSER_ACTION_OPEN,
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -179,7 +179,7 @@ main( int argc, char **argv)
 
 
 
-void
+static void
 edf_data_to_widgets( const sigfile::CEDFFile& F)
 {
 	gtk_label_set_markup( lLabel, (string ("<b>File:</b> <i>") + F.filename() + "</i>").c_str());
@@ -206,7 +206,7 @@ edf_data_to_widgets( const sigfile::CEDFFile& F)
 
 
 
-void
+static void
 widgets_to_edf_data( sigfile::CEDFFile& F)
 {
 	memcpy( F.header.patient_id,     strpad( gtk_entry_get_text( e[PatientID]),     80).c_str(), 80);
@@ -216,17 +216,18 @@ widgets_to_edf_data( sigfile::CEDFFile& F)
 	memcpy( F.header.reserved,       strpad( gtk_entry_get_text( e[Reserved]),      44).c_str(), 44);
 
 	auto H = channels_tmp.begin();
-	for ( auto h = F.signals.begin(); h != F.signals.end(); ++h, ++H ) {
-		memcpy( h->header.label,		strpad( H->Label,           16).c_str(), 16);
-		memcpy( h->header.physical_dim,		strpad( H->PhysicalDim,      8).c_str(),  8);
-		memcpy( h->header.physical_min,		strpad( H->PhysicalMin,      8).c_str(),  8);
-		memcpy( h->header.physical_max,		strpad( H->PhysicalMax,      8).c_str(),  8);
-		memcpy( h->header.digital_min,		strpad( H->DigitalMin,       8).c_str(),  8);
-		memcpy( h->header.digital_max,		strpad( H->DigitalMax,       8).c_str(),  8);
-		memcpy( h->header.transducer_type,	strpad( H->TransducerType,  80).c_str(), 80);
-		memcpy( h->header.filtering_info,	strpad( H->FilteringInfo,   80).c_str(), 80);
-		memcpy( h->header.samples_per_record,	strpad( H->SamplesPerRecord, 8).c_str(),  8);
-		memcpy( h->header.reserved,		strpad( H->Reserved,        32).c_str(), 32);
+	for ( auto& h : F.signals ) {
+		memcpy( h.header.label,			strpad( H->Label,           16).c_str(), 16);
+		memcpy( h.header.physical_dim,		strpad( H->PhysicalDim,      8).c_str(),  8);
+		memcpy( h.header.physical_min,		strpad( H->PhysicalMin,      8).c_str(),  8);
+		memcpy( h.header.physical_max,		strpad( H->PhysicalMax,      8).c_str(),  8);
+		memcpy( h.header.digital_min,		strpad( H->DigitalMin,       8).c_str(),  8);
+		memcpy( h.header.digital_max,		strpad( H->DigitalMax,       8).c_str(),  8);
+		memcpy( h.header.transducer_type,	strpad( H->TransducerType,  80).c_str(), 80);
+		memcpy( h.header.filtering_info,	strpad( H->FilteringInfo,   80).c_str(), 80);
+		memcpy( h.header.samples_per_record,	strpad( H->SamplesPerRecord, 8).c_str(),  8);
+		memcpy( h.header.reserved,		strpad( H->Reserved,        32).c_str(), 32);
+		++H;
 	}
 }
 
@@ -234,7 +235,7 @@ widgets_to_edf_data( sigfile::CEDFFile& F)
 
 
 
-void
+static void
 current_channel_data_to_widgets()
 {
 	GString *tmp = g_string_new("");
@@ -250,15 +251,15 @@ current_channel_data_to_widgets()
 	gtk_entry_set_text( e[ChannelPhysicalDim],	strtrim( HTmpi->PhysicalDim) . c_str());
 	gtk_entry_set_text( e[ChannelPhysicalMin],	strtrim( HTmpi->PhysicalMin) . c_str());
 	gtk_entry_set_text( e[ChannelPhysicalMax],	strtrim( HTmpi->PhysicalMax) . c_str());
-	gtk_entry_set_text( e[ChannelDigitalMin],		strtrim( HTmpi->DigitalMin ) . c_str());
-	gtk_entry_set_text( e[ChannelDigitalMax],		strtrim( HTmpi->DigitalMax ) . c_str());
+	gtk_entry_set_text( e[ChannelDigitalMin],	strtrim( HTmpi->DigitalMin ) . c_str());
+	gtk_entry_set_text( e[ChannelDigitalMax],	strtrim( HTmpi->DigitalMax ) . c_str());
 	gtk_entry_set_text( e[ChannelTransducerType],	strtrim( HTmpi->TransducerType) . c_str());
 	gtk_entry_set_text( e[ChannelFilteringInfo],	strtrim( HTmpi->FilteringInfo)  . c_str());
 	gtk_entry_set_text( e[ChannelSamplesPerRecord],	strtrim( HTmpi->SamplesPerRecord) . c_str());
 	gtk_entry_set_text( e[ChannelReserved],		strtrim( HTmpi->Reserved)         . c_str());
 }
 
-void
+static void
 widgets_to_current_channel_data()
 {
 	HTmpi->Label		= gtk_entry_get_text( e[ChannelLabel]);
@@ -274,54 +275,38 @@ widgets_to_current_channel_data()
 }
 
 
-bool
+static bool
 validate_all_widgets()
 {
+	const char *str, *p;
+	struct tm ts;
+	str = gtk_entry_get_text( e[RecordingDate]);
+	p = strptime( str, "%d.%m.%y", &ts);
+	if ( strlen(str) != 8 || p == NULL || *p != '\0' )
+		return false;
+	str = gtk_entry_get_text( e[RecordingTime]);
+	p = strptime( str, "%H.%M.%S", &ts);
+	if ( strlen(str) != 8 || p == NULL || *p != '\0' )
+		return false;
+
+	char *tail;
+	double p_min, p_max;
+	int d_min, d_max;
+	if ( (p_min = strtod( gtk_entry_get_text( e[ChannelPhysicalMin]), &tail), *tail != '\0') )
+		return false;
+	if ( (p_max = strtod( gtk_entry_get_text( e[ChannelPhysicalMax]), &tail), *tail != '\0') )
+		return false;
+	if ( (d_min = strtoul( gtk_entry_get_text( e[ChannelDigitalMin]), &tail, 10), *tail != '\0') )
+		return false;
+	if ( (d_max = strtoul( gtk_entry_get_text( e[ChannelDigitalMax]), &tail, 10), *tail != '\0') )
+		return false;
+	if ( p_min >= p_max || d_min >= d_max )
+		return false;
+
 	return true;
 }
 
 
-bool
-validate_text_entry_buffer( const char *str, size_t i)
-{
-	char *tail;
-	switch ( i ) {
-	case PatientID:
-	case RecordingID:
-		return true;
-	case RecordingDate:
-	{
-		struct tm ts;
-		char *p = strptime( str, "%d.%m.%y", &ts);
-		return strlen(str) == 8 && p && *p == '\0';
-	}
-	case RecordingTime:
-	{
-		struct tm ts;
-		char *p = strptime( str, "%H.%M.%S", &ts);
-		return strlen(str) == 8 && p && *p == '\0';
-	}
-	case Reserved:
-	case ChannelLabel:
-	case ChannelPhysicalDim:
-		return true;
-	case ChannelPhysicalMin:
-	case ChannelPhysicalMax:
-#pragma GCC diagnostic ignored "-Wunused-result"
-		return strtod( str, &tail), *tail == '\0';
-	case ChannelDigitalMin:
-	case ChannelDigitalMax:
-		return strtol( str, &tail, 10), *tail == '\0';
-	case ChannelTransducerType:
-	case ChannelFilteringInfo:
-	case ChannelReserved:
-		return true;
-	case ChannelSamplesPerRecord:
-		return strtol( str, &tail, 10), *tail == '\0';
-#pragma GCC diagnostic warning "-Wunused-result"
-	}
-	return false; // wtf is i?
-}
 
 extern "C" void
 bNext_clicked_cb( GtkButton *button, gpointer userdata)
@@ -355,9 +340,7 @@ inserted_text_cb( GtkEntryBuffer *buffer,
 		  guint           n_chars,
 		  gpointer        userdata)
 {
-	gtk_widget_set_sensitive( (GtkWidget*)bWrite,
-				  validate_text_entry_buffer( gtk_entry_buffer_get_text( buffer),
-							      (size_t)userdata));
+	gtk_widget_set_sensitive( (GtkWidget*)bWrite, validate_all_widgets());
 }
 extern "C" void
 deleted_text_cb( GtkEntryBuffer *buffer,
@@ -365,9 +348,7 @@ deleted_text_cb( GtkEntryBuffer *buffer,
 		 guint           n_chars,
 		 gpointer        userdata)
 {
-	gtk_widget_set_sensitive( (GtkWidget*)bWrite,
-				  validate_text_entry_buffer( gtk_entry_buffer_get_text( buffer),
-							      (size_t)userdata));
+	gtk_widget_set_sensitive( (GtkWidget*)bWrite, validate_all_widgets());
 }
 
 void
