@@ -36,7 +36,8 @@ aghui::SExpDesignUI::populate_2()
 				    -1);
 
 		for ( auto &J : G.second ) {
-			if ( not J.have_session(*_AghDi) ) // subject lacking one
+			if ( not J.have_session(*_AghDi) or
+			     J.measurements[*_AghDi].episodes.empty() ) // subject lacking one
 				continue;
 
 			gtk_tree_store_append( mSimulations, &iter_j, &iter_g);
@@ -75,8 +76,8 @@ aghui::SExpDesignUI::populate_2()
 							    -1);
 
 					// tunable columns
-					for ( agh::TTunable_underlying_type t = 0; t < M.cur_tset.size(); ++t ) {
-						auto tg = min((size_t)t, (size_t)agh::TTunable::_basic_tunables - 1);
+					for ( size_t t = 0; t < M.cur_tset.size(); ++t ) {
+						auto tg = min(t, (size_t)agh::TTunable::_basic_tunables - 1);
 						const auto& td = agh::STunableSet::stock[tg];
 						snprintf_buf( td.fmt,
 							      M.cur_tset[t] * td.display_scale_factor);
