@@ -11,8 +11,7 @@
  */
 
 
-
-
+#include <sys/time.h>
 #include <cairo/cairo.h>
 
 #include "misc.hh"
@@ -186,7 +185,12 @@ daSFMontage_button_press_event_cb( GtkWidget *wid, GdkEventButton *event, gpoint
 
 
 
-
+inline double
+timeval_elapsed( const struct timeval &x, const struct timeval &y)
+{
+	return y.tv_sec - x.tv_sec
+		+ 1e-6 * (y.tv_usec - x.tv_usec);
+}
 
 gboolean
 daSFMontage_motion_notify_event_cb( GtkWidget *wid, GdkEventMotion *event, gpointer userdata)
@@ -195,6 +199,10 @@ daSFMontage_motion_notify_event_cb( GtkWidget *wid, GdkEventMotion *event, gpoin
 	if ( SF.mode == aghui::SScoringFacility::TMode::showing_ics )
 		return TRUE;
 
+	static struct timeval last_page_flip = {0, 0};
+	if ( last_page_flip.tv_sec == 0 )
+		gettimeofday( &last_page_flip, NULL);
+
 	// update marquee boundaries
 	if ( SF.mode == aghui::SScoringFacility::TMode::shuffling_channels ) {
 		SF.using_channel->zeroy = SF.zeroy_before_shuffling + (event->y - SF.event_y_when_shuffling);
@@ -204,15 +212,30 @@ daSFMontage_motion_notify_event_cb( GtkWidget *wid, GdkEventMotion *event, gpoin
 		if ( SF.channel_near( event->y) != SF.using_channel ) // user has dragged too much vertically
 			return TRUE;
 		SF.using_channel->marquee_mend = event->x;
+
+		struct timeval currently;
+		gettimeofday( &currently, NULL);
+		if ( (int)event->x > SF.da_wd && SF.cur_vpage() < SF.total_vpages()-1 ) {
+			if ( timeval_elapsed( last_page_flip, currently) > .4 ) {
+				// x (1+2a) = y
+				SF.using_channel->marquee_mstart -= SF.da_wd / (1. + 2*SF.skirting_run_per1);
+				SF.set_cur_vpage( SF.cur_vpage()+1);
+				gettimeofday( &last_page_flip, NULL);
+			}
+		} else if ( (int)event->x < 0 && SF.cur_vpage() > 0 ) {
+			if ( timeval_elapsed( last_page_flip, currently) > .4 ) {
+				SF.using_channel->marquee_mstart += SF.da_wd / (1. + 2*SF.skirting_run_per1);
+				SF.set_cur_vpage( SF.cur_vpage()-1);
+				gettimeofday( &last_page_flip, NULL);
+			}
+		}
 		SF.using_channel->marquee_to_selection(); // to be sure, also do it on button_release
 		if ( event->state & GDK_SHIFT_MASK )
-			for_each( SF.channels.begin(), SF.channels.end(),
-				  [&] (SScoringFacility::SChannel& H)
-				  {
-					  H.marquee_mstart = SF.using_channel->marquee_mstart;
-					  H.marquee_mend = event->x;
-					  H.marquee_to_selection(); // to be sure, also do it on button_release
-				  });
+			for( auto &H : SF.channels ) {
+				H.marquee_mstart = SF.using_channel->marquee_mstart;
+				H.marquee_mend = event->x;
+				H.marquee_to_selection(); // to be sure, also do it on button_release
+			}
 		gtk_widget_queue_draw( wid);
 
 	} else if ( SF.draw_crosshair ) {
@@ -255,20 +278,22 @@ daSFMontage_button_release_event_cb( GtkWidget *wid, GdkEventButton *event, gpoi
 
 	switch ( event->button ) {
 	case 1:
-		if ( SF.mode == aghui::SScoringFacility::TMode::marking
-		     && fabs(SF.using_channel->marquee_mstart - SF.using_channel->marquee_mend) > 5 ) {
-			//gtk_widget_queue_draw( wid);
-			gtk_menu_popup( SF.mSFPageSelection,
-					NULL, NULL, NULL, NULL, 3, event->time);
+		if ( SF.mode == aghui::SScoringFacility::TMode::marking ) {
+			SF.mode = aghui::SScoringFacility::TMode::scoring;
+			gtk_widget_queue_draw( wid);
+			if ( fabs(SF.using_channel->marquee_mstart - SF.using_channel->marquee_mend) > 5 ) {
+				gtk_menu_popup( SF.mSFPageSelection,
+						NULL, NULL, NULL, NULL, 3, event->time);
+			}
 		} else if ( Ch->type == sigfile::SChannel::TType::eeg &&
 			    Ch->draw_power && event->y > Ch->zeroy )
 			gtk_spin_button_set_value( SF.eSFCurrentPage,
 						   (event->x / SF.da_wd) * SF.total_vpages()+1);
 		else {
 			SF.using_channel->marquee_to_selection();
+			SF.mode = aghui::SScoringFacility::TMode::scoring;
 			gtk_widget_queue_draw( wid);
 		}
-		SF.mode = aghui::SScoringFacility::TMode::scoring;
 	    break;
 	case 3:
 	    break;
