@@ -19,6 +19,7 @@
 
 #include "../libexstrom/exstrom.hh"
 #include "../misc.hh"
+#include "../fs.hh"
 #include "misc.hh"
 #include "ui.hh"
 #include "expdesign.hh"
@@ -364,6 +365,7 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 	crosshair_at (10),
 	draw_crosshair (false),
 	draw_spp (true),
+	alt_hypnogram (false),
 	pagesize_item (figure_display_pagesize_item( parent.pagesize())),
 	_cur_page (0),
 	_cur_vpage (0),
@@ -432,13 +434,14 @@ aghui::SScoringFacility::SScoringFacility( agh::CSubject& J,
 
       // load montage
 	{
-		ifstream ifs (sigfile::make_fname__common( channels.front().crecording.F().filename(), true) + ".montage");
+		ifstream ifs (fs::make_fname_base( channels.front().crecording.F().filename(), ".edf", true) + ".montage");
 		if ( ifs.good() ) {
 			ifs >> draw_crosshair >> draw_spp
 			    >> sane_signal_display_scale >> sane_power_display_scale
 			    // >> skirting_run_per1
 			    >> interchannel_gap
-			    >> n_hidden;
+			    >> n_hidden
+			    >> alt_hypnogram;
 			for_each( channels.begin(), channels.end(),
 				  [&] ( SChannel& h)
 				  {
@@ -596,13 +599,13 @@ aghui::SScoringFacility::~SScoringFacility()
 
 	// save display scales
 	{
-		ofstream ofs (sigfile::make_fname__common( channels.front().crecording.F().filename(), true) + ".montage");
+		ofstream ofs (fs::make_fname_base( channels.front().crecording.F().filename(), ".edf", true) + ".montage");
 		if ( ofs.good() ) {
 			ofs << draw_crosshair << ' ' << draw_spp << ' '
 			    << sane_signal_display_scale << ' ' << sane_power_display_scale << ' '
 			    // << skirting_run_per1 << ' '
 			    << interchannel_gap << ' '
-			    << n_hidden << ' ' << endl;
+			    << n_hidden << ' ' << alt_hypnogram << ' ' << endl;
 			for ( auto &H : channels )
 				ofs << H.hidden << ' '
 				    << H.draw_zeroline << ' ' << H.draw_original_signal << ' '
@@ -786,10 +789,13 @@ aghui::SScoringFacility::do_score_back( char score_ch)
 size_t
 aghui::SScoringFacility::SChannel::marquee_to_selection()
 {
-	if ( marquee_mstart < marquee_mend)
-		marquee_start = marquee_mstart, marquee_end = marquee_mend;
-	else
-		marquee_start = marquee_mend, marquee_end = marquee_mstart;
+	if ( marquee_mstart < marquee_mend) {
+		marquee_start = marquee_mstart;
+		marquee_end = marquee_mend;
+	} else {
+		marquee_start = marquee_mend;
+		marquee_end = marquee_mstart;
+	}
 
 	selection_start = sample_at_click( marquee_start);
 	selection_end   = sample_at_click( marquee_end);
@@ -1495,6 +1501,7 @@ const char* const
 	"\n"
 	"<b>Hypnogram:</b>\n"
 	"  Click1:	position cursor;\n"
+	"  Click2:	alt view;\n"
 	"  Click3:	context menu.",
 
 	"<b>ICA:</b>\n"
